@@ -111,6 +111,34 @@ class FairdConfig:
     def neo4j_password(self):
         return self.get('neo4j_password')
 
+    @property
+    def data_mongodb_host(self):
+        return self.get('data.mongodb.host', '')
+
+    @property
+    def data_mongodb_port(self):
+        return self.get('data.mongodb.port', '')
+
+    @property
+    def data_mongodb_database(self):
+        return self.get('data.mongodb.database', '')
+
+    @property
+    def data_mongodb_collection(self):
+        return self.get('data.mongodb.collection', '')
+
+    @property
+    def data_mongodb_username(self):
+        return self.get('data.mongodb.username', '')
+
+    @property
+    def data_mongodb_password(self):
+        return self.get('data.mongodb.password', '')
+
+    @property
+    def dataset_base_path_field(self):
+        return self.get('dataset.base.path.field', '')
+
 class FairdConfigManager:
     _config = None
 
