@@ -10,7 +10,6 @@ import socket
 from utils.logger_utils import get_logger
 logger = get_logger(__name__)
 import requests
-
 from sdk.connection_pool import FlightConnectionPool, ConnectionManager
 
 
@@ -237,6 +236,8 @@ class DacpClient:
 
     def get_dataframe_stream(self, dataframe_name: str, token: str, max_chunksize: Optional[int] = 1024 * 1024 * 5
                              , username: Optional[str] = None , mount_timestamp: Optional[str] = None):
+        if not token:
+            raise ValueError("token is none")
         if not username :
             username = self.__principal.params.get('username')
         ips = self.get_ips()
@@ -247,22 +248,35 @@ class DacpClient:
             'dataframe_name': dataframe_name,
             'token': token,
             'username': username,
-
             "public_ip": public_ip,
             "private_ip": private_ip,
-
             'max_chunksize': max_chunksize,
             'mount_timestamp': mount_timestamp,
-
             'connection_id': self.__connection_id
         }
         # 获取数据流
         with ConnectionManager.get_connection() as conn:
-            reader = conn.do_action(pa.flight.Action("get_dataframe_stream", json.dumps(ticket).encode('utf-8')))
-            for chunk in reader:
-                chunk_bytes = chunk.body.to_pybytes()
-                print(f"Successfully fetch {len(chunk_bytes)} Bytes")
-                yield chunk_bytes
+            stream_generator = conn.do_action(
+                pa.flight.Action("get_dataframe_stream", json.dumps(ticket).encode('utf-8')))
+            # 1. 尝试获取第一个数据块并检查其内容
+            try:
+                first_chunk = next(stream_generator)
+                chunk_bytes = first_chunk.body.to_pybytes()
+            except StopIteration:
+                logger.error(f"数据获取失败: 没有数据可供获取")
+                raise ValueError("数据获取失败: 没有数据可供获取")
+
+            try:
+                error_info = json.loads(chunk_bytes.decode('utf-8'))
+                if 'status' in error_info and error_info['status'] == 'error' and error_info['code'] == 401:
+                    logger.error(f"数据获取失败: {error_info['msg']}")
+                    raise ValueError(error_info)
+            except (json.JSONDecodeError, UnicodeDecodeError):
+                pass
+
+            yield chunk_bytes
+            for chunk in stream_generator:
+                yield chunk.body.to_pybytes()
 
 class AuthType(Enum):
     OAUTH = "oauth"
